@@ -400,8 +400,9 @@ di_getDiskInfo (diskInfo, diCount)
  *
  */
 
-# define DI_GETDISKINFO_DEF   1
-# define MSDOS_BUFFER_SIZE    256
+# define DI_GETDISKINFO_DEF 1
+
+# define MSDOS_BUFFER_SIZE          256
 
 void
 # if _proto_stdc
@@ -424,10 +425,9 @@ di_getDiskInfo (diskInfo, diCount)
 
 # if _lib_GetDiskFreeSpaceEx
     if (debug > 0) { printf ("# getDiskInfo: GetDiskFreeSpaceEx\n"); }
-# else
-#  if _lib_GetDiskFreeSpace
-      if (debug > 0) { printf ("# getDiskInfo: GetDiskFreeSpace\n"); }
-#  endif
+# endif
+# if _lib_GetDiskFreeSpace
+    if (debug > 0) { printf ("# getDiskInfo: GetDiskFreeSpace\n"); }
 # endif
     if (debug > 0) { printf ("# getDiskInfo: GetVolumeInformation\n"); }
     for (i = 0; i < *diCount; ++i)
