@@ -1,7 +1,5 @@
 /*
- * $Id$
- * $Source$
- * Copyright 2011-2013 Brad Lanam, Walnut Creek, CA
+ * Copyright 2011-2018 Brad Lanam, Walnut Creek, CA
  */
 
 /*
@@ -199,7 +197,7 @@ dooptchecks (info, opt, optinfo, tag, sz)
   return 0;
 }
 
-static void
+static int
 #if _proto_stdc
 process_opt (getoptn_info_t *info, getoptn_opt_t *opt, getoptn_optinfo_t *optinfo)
 #else
@@ -222,56 +220,56 @@ process_opt (info, opt, optinfo)
     ptr = getoption_value (info, opt);
     if (ptr == (char *) NULL) {
       fprintf (stderr, "%s: %s argument missing\n", info->argv[0], info->arg);
-      return;
+      return 1;
     }
   }
 
   if (opt->option_type == GETOPTN_BOOL) {
     int       *v;
     if (dooptchecks (info, opt, optinfo, "bool", sizeof(int)) != 0) {
-      return;
+      return 1;
     }
     v = (int *) opt->valptr;
     *v = 1 - *v;  /* flip it */
   } else if (opt->option_type == GETOPTN_INT) {
     int       *v;
     if (dooptchecks (info, opt, optinfo, "int", sizeof(int)) != 0) {
-      return;
+      return 1;
     }
     v = (int *) opt->valptr;
     *v = atoi (ptr);
   } else if (opt->option_type == GETOPTN_LONG) {
     long      *v;
     if (dooptchecks (info, opt, optinfo, "long", sizeof(long)) != 0) {
-      return;
+      return 1;
     }
     v = (long *) opt->valptr;
     *v = atol (ptr);
   } else if (opt->option_type == GETOPTN_SIZET) {
     Size_t  *v;
     if (dooptchecks (info, opt, optinfo, "Size_t", sizeof(Size_t)) != 0) {
-      return;
+      return 1;
     }
     v = (Size_t *) opt->valptr;
     *v = (Size_t) atol (ptr);
   } else if (opt->option_type == GETOPTN_DOUBLE) {
     double     *v;
     if (dooptchecks (info, opt, optinfo, "double", sizeof(double)) != 0) {
-      return;
+      return 1;
     }
     v = (double *) opt->valptr;
     *v = atof (ptr);
   } else if (opt->option_type == GETOPTN_STRING) {
     char      *v;
     if (dooptchecks (info, opt, optinfo, "string", 0) != 0) {
-      return;
+      return 1;
     }
     v = (char *) opt->valptr;
     strncpy (v, ptr, opt->valsiz - 1);
   } else if (opt->option_type == GETOPTN_STRPTR) {
     const char **v;
     if (dooptchecks (info, opt, optinfo, "strptr", 0) != 0) {
-      return;
+      return 1;
     }
     v = (const char **) opt->valptr;
     *v = strdup (ptr); /* memory leak (one time) */
@@ -279,7 +277,7 @@ process_opt (info, opt, optinfo)
     getoptn_func_bool_t f;
     if (opt->value2 == (void *) NULL) {
       fprintf (stderr, "%s: %s: invalid function ptr (line %d)\n", info->argv[0], "func_bool", optinfo->idx);
-      return;
+      return 1;
     }
     f = (getoptn_func_bool_t) opt->value2;
     (f)(opt->option, opt->valptr);
@@ -287,7 +285,7 @@ process_opt (info, opt, optinfo)
     getoptn_func_value_t f;
     if (opt->value2 == (void *) NULL) {
       fprintf (stderr, "%s: %s: invalid function ptr (line %d)\n", info->argv[0], "func_val", optinfo->idx);
-      return;
+      return 1;
     }
     f = (getoptn_func_value_t) opt->value2;
     (f)(opt->option, opt->valptr, ptr);
@@ -296,24 +294,29 @@ process_opt (info, opt, optinfo)
     info->offset = 0;
     fprintf (stderr, "%s: unknown option type %d\n",
          info->argv[0], opt->option_type);
+    return 1;
   }
+
+  return 0;
 }
 
 
 int
 #if _proto_stdc
-getoptn (int style, int argc, const char * const argv [], Size_t optcount,
-         getoptn_opt_t opts [])
+getoptn (int style, int argc, const char * const argv [],
+         Size_t optcount, getoptn_opt_t opts [], int *errorCount)
 #else
-getoptn (style, argc, argv, optcount, opts)
+getoptn (style, argc, argv, optcount, opts, errorCount)
     int         style;
     int         argc;
     const char * const argv [];
     Size_t      optcount;
     getoptn_opt_t opts [];
+    int         *errorCount;
 #endif
 {
   int               i;
+  int               rc;
   const char        *arg;
   getoptn_opt_t     *opt;
   getoptn_info_t    info;
@@ -325,6 +328,8 @@ getoptn (style, argc, argv, optcount, opts)
   info.opts = opts;
   info.optinfo = (getoptn_optinfo_t *) NULL;
 
+  *errorCount = 0;
+
   if (optcount > 0) {
     info.optinfo = (getoptn_optinfo_t *)
           malloc (sizeof (getoptn_optinfo_t) * optcount);
@@ -365,12 +370,16 @@ getoptn (style, argc, argv, optcount, opts)
       if (i == GETOPTN_NOTFOUND) {
         if (info.reprocess == FALSE) {
           fprintf (stderr, "%s: unknown option %s\n", argv[0], arg);
+          ++*errorCount;
         }
         continue;
       }
 
       opt = &opts[i];
-      process_opt (&info, opt, &info.optinfo[i]);
+      rc = process_opt (&info, opt, &info.optinfo[i]);
+      if (rc) {
+        ++*errorCount;
+      }
     } while (info.reprocess);
   }
 
@@ -439,11 +448,11 @@ main (argc, argv)
   int       i;
   int       j;
   int       k;
+  int       ec;
   int       optidx;
   int       ac;
   const char *av[10];
 
-  int  rc;
   int  grc = 0;
   int  testno = 0;
 
@@ -485,9 +494,10 @@ main (argc, argv)
   av[0] = tmp;
   av[1] = "-D";
   av[2] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_LEGACY, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (strcmp (s, "abc123") != 0 || optidx != 2) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (strcmp (s, "abc123") != 0 || optidx != 2 || ec != 0) {
     fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
@@ -500,9 +510,10 @@ main (argc, argv)
   av[0] = tmp;
   av[1] = "-b";
   av[2] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_LEGACY, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (i != 1 || optidx != 2) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (i != 1 || optidx != 2 || ec != 0) {
     fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
@@ -515,9 +526,10 @@ main (argc, argv)
   av[0] = tmp;
   av[1] = "--b";
   av[2] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_LEGACY, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (i != 1 || optidx != 2) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (i != 1 || optidx != 2 || ec != 0) {
     fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
@@ -530,9 +542,10 @@ main (argc, argv)
   av[0] = tmp;
   av[1] = "--i=13";
   av[2] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_LEGACY, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (i != 13 || optidx != 2) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (i != 13 || optidx != 2 || ec != 0) {
     fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
@@ -546,9 +559,10 @@ main (argc, argv)
   av[1] = "--i";
   av[2] = "14";
   av[3] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_LEGACY, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (i != 14 || optidx != 3) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (i != 14 || optidx != 3 || ec != 0) {
     fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
@@ -562,9 +576,10 @@ main (argc, argv)
   av[0] = tmp;
   av[1] = "-i15";
   av[2] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_LEGACY, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (i != 15 || j != 0 || optidx != 2) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (i != 15 || j != 0 || optidx != 2 || ec != 0) {
     fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
@@ -578,9 +593,10 @@ main (argc, argv)
   av[1] = "-i";
   av[2] = "16";
   av[3] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_LEGACY, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (i != 16 || optidx != 3) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (i != 16 || optidx != 3 || ec != 0) {
     fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
@@ -595,9 +611,10 @@ main (argc, argv)
   av[1] = "-i17";
   av[2] = "5";
   av[3] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_MODERN, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (i != 0 || j != 5 || optidx != 3) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (i != 0 || j != 5 || optidx != 3 || ec != 0) {
     fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
@@ -610,9 +627,10 @@ main (argc, argv)
   av[0] = tmp;
   av[1] = "-i=17";
   av[2] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_MODERN, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (i != 17 || optidx != 2) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (i != 17 || optidx != 2 || ec != 0) {
     fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
@@ -625,9 +643,10 @@ main (argc, argv)
   av[0] = tmp;
   av[1] = "-i7";
   av[2] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_LEGACY, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (i != 7 || optidx != 2) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (i != 7 || optidx != 2 || ec != 0) {
     fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
@@ -641,9 +660,10 @@ main (argc, argv)
   av[1] = "-l";
   av[2] = "19";
   av[3] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_LEGACY, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (l != 19 || optidx != 3) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (l != 19 || optidx != 3 || ec != 0) {
     fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
@@ -658,9 +678,10 @@ main (argc, argv)
   av[1] = "-b";
   av[2] = "-c";
   av[3] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_LEGACY, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (i != 1 || j != 1 || optidx != 3) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (i != 1 || j != 1 || optidx != 3 || ec != 0) {
     fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
@@ -675,9 +696,10 @@ main (argc, argv)
   av[0] = tmp;
   av[1] = "-bc";
   av[2] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_LEGACY, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (i != 1 || j != 1 || k != 0 || optidx != 2) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (i != 1 || j != 1 || k != 0 || optidx != 2 || ec != 0) {
     fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
@@ -692,9 +714,10 @@ main (argc, argv)
   av[0] = tmp;
   av[1] = "-bc";
   av[2] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_MODERN, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (i != 0 || j != 0 || k != 1 || optidx != 2) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (i != 0 || j != 0 || k != 1 || optidx != 2 || ec != 0) {
     fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
@@ -707,9 +730,10 @@ main (argc, argv)
   av[0] = tmp;
   av[1] = "-s=abc";
   av[2] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_MODERN, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (strcmp (s, "abc") != 0 || optidx != 2) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (strcmp (s, "abc") != 0 || optidx != 2 || ec != 0) {
     fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
@@ -722,9 +746,10 @@ main (argc, argv)
   av[0] = tmp;
   av[1] = "-d=1.2";
   av[2] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_MODERN, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (fabs(d - 1.2) > 0.00001 || optidx != 2) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (fabs(d - 1.2) > 0.00001 || optidx != 2 || ec != 0) {
     fprintf (stderr, "fail test %d: %.2g %d\n", testno, d, optidx);
     grc = 1;
   }
@@ -738,9 +763,10 @@ main (argc, argv)
   av[0] = tmp;
   av[1] = "-sabcd";
   av[2] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_LEGACY, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (strcmp (s, "abcd") != 0 || i != 0 || optidx != 2) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (strcmp (s, "abcd") != 0 || i != 0 || optidx != 2 || ec != 0) {
     fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
@@ -753,9 +779,10 @@ main (argc, argv)
   av[0] = tmp;
   av[1] = "-s=abcde";
   av[2] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_MODERN, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (strcmp (s, "abcde") != 0 || optidx != 2) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (strcmp (s, "abcde") != 0 || optidx != 2 || ec != 0) {
     fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
@@ -769,9 +796,10 @@ main (argc, argv)
   av[1] = "-s";
   av[2] = "abcdef";
   av[3] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_MODERN, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (strcmp (s, "abcdef") != 0 || optidx != 3) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (strcmp (s, "abcdef") != 0 || optidx != 3 || ec != 0) {
     fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
@@ -785,9 +813,10 @@ main (argc, argv)
   av[1] = "-sp";
   av[2] = "0123";
   av[3] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_MODERN, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (strcmp (sp, "0123") != 0 || optidx != 3) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (strcmp (sp, "0123") != 0 || optidx != 3 || ec != 0) {
     fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
@@ -800,9 +829,26 @@ main (argc, argv)
   av[0] = tmp;
   av[1] = "-sp=01234";
   av[2] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_MODERN, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (strcmp (sp, "01234") != 0 || optidx != 2) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (strcmp (sp, "01234") != 0 || optidx != 2 || ec != 0) {
+    fprintf (stderr, "fail test %d\n", testno);
+    grc = 1;
+  }
+
+  /* test 22 */
+  ++testno;
+  sp = "";
+  ac = 2;
+  sprintf (tmp, "test %d", testno);
+  av[0] = tmp;
+  av[1] = "-p012345";
+  av[2] = NULL;
+  ec = 0;
+  optidx = getoptn (GETOPTN_LEGACY, ac, av,
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (strcmp (sp, "012345") != 0 || optidx != 2 || ec != 0) {
     fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
@@ -813,11 +859,12 @@ main (argc, argv)
   ac = 2;
   sprintf (tmp, "test %d", testno);
   av[0] = tmp;
-  av[1] = "-p012345";
+  av[1] = "-S";
   av[2] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_LEGACY, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (strcmp (sp, "012345") != 0 || optidx != 2) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (strcmp (sp, "abc1234") != 0 || optidx != 2 || ec != 0) {
     fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
@@ -828,32 +875,18 @@ main (argc, argv)
   ac = 2;
   sprintf (tmp, "test %d", testno);
   av[0] = tmp;
-  av[1] = "-S";
+  av[1] = "-p=0123456";
   av[2] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_LEGACY, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (strcmp (sp, "abc1234") != 0 || optidx != 2) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (strcmp (sp, "0123456") != 0 || optidx != 2 || ec != 0) {
     fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
 
   /* test 25 */
   ++testno;
-  sp = "";
-  ac = 2;
-  sprintf (tmp, "test %d", testno);
-  av[0] = tmp;
-  av[1] = "-p=0123456";
-  av[2] = NULL;
-  optidx = getoptn (GETOPTN_LEGACY, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (strcmp (sp, "0123456") != 0 || optidx != 2) {
-    fprintf (stderr, "fail test %d\n", testno);
-    grc = 1;
-  }
-
-  /* test 26 */
-  ++testno;
   memset (s, '\0', sizeof (s));
   i = 0;
   ac = 2;
@@ -861,9 +894,26 @@ main (argc, argv)
   av[0] = tmp;
   av[1] = "-sabcd";
   av[2] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_MODERN, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (strcmp (s, "") != 0 || i != 1 || optidx != 2) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (strcmp (s, "") != 0 || i != 1 || optidx != 2 || ec != 0) {
+    fprintf (stderr, "fail test %d\n", testno);
+    grc = 1;
+  }
+
+  /* test 26 */
+  ++testno;
+  i = 1;
+  ac = 2;
+  sprintf (tmp, "test %d", testno);
+  av[0] = tmp;
+  av[1] = "-b";
+  av[2] = NULL;
+  ec = 0;
+  optidx = getoptn (GETOPTN_LEGACY, ac, av,
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (i != 0 || optidx != 2 || ec != 0) {
     fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
@@ -874,11 +924,12 @@ main (argc, argv)
   ac = 2;
   sprintf (tmp, "test %d", testno);
   av[0] = tmp;
-  av[1] = "-b";
+  av[1] = "--b";
   av[2] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_LEGACY, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (i != 0 || optidx != 2) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (i != 0 || optidx != 2 || ec != 0) {
     fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
@@ -886,21 +937,6 @@ main (argc, argv)
   /* test 28 */
   ++testno;
   i = 1;
-  ac = 2;
-  sprintf (tmp, "test %d", testno);
-  av[0] = tmp;
-  av[1] = "--b";
-  av[2] = NULL;
-  optidx = getoptn (GETOPTN_LEGACY, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (i != 0 || optidx != 2) {
-    fprintf (stderr, "fail test %d\n", testno);
-    grc = 1;
-  }
-
-  /* test 29 */
-  ++testno;
-  i = 1;
   j = 1;
   ac = 3;
   sprintf (tmp, "test %d", testno);
@@ -908,13 +944,32 @@ main (argc, argv)
   av[1] = "-b";
   av[2] = "-c";
   av[3] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_LEGACY, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (i != 0 || j != 0 || optidx != 3) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (i != 0 || j != 0 || optidx != 3 || ec != 0) {
     fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
 
+  /* test 29 */
+  ++testno;
+  i = 1;
+  j = 1;
+  k = 1;
+  ac = 2;
+  sprintf (tmp, "test %d", testno);
+  av[0] = tmp;
+  av[1] = "-bc";
+  av[2] = NULL;
+  ec = 0;
+  optidx = getoptn (GETOPTN_LEGACY, ac, av,
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (i != 0 || j != 0 || k != 1 || optidx != 2 || ec != 0) {
+    fprintf (stderr, "fail test %d / i:%d j:%d k:%d optidx:%d ec:%d\n", testno, i, j, k, optidx, ec);
+    grc = 1;
+  }
+
   /* test 30 */
   ++testno;
   i = 1;
@@ -925,31 +980,15 @@ main (argc, argv)
   av[0] = tmp;
   av[1] = "-bc";
   av[2] = NULL;
-  optidx = getoptn (GETOPTN_LEGACY, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (i != 0 || j != 0 || k != 1 || optidx != 2) {
-    fprintf (stderr, "fail test %d\n", testno);
-    grc = 1;
-  }
-
-  /* test 31 */
-  ++testno;
-  i = 1;
-  j = 1;
-  k = 1;
-  ac = 2;
-  sprintf (tmp, "test %d", testno);
-  av[0] = tmp;
-  av[1] = "-bc";
-  av[2] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_MODERN, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (i != 1 || j != 1 || k != 0 || optidx != 2) {
-    fprintf (stderr, "fail test %d\n", testno);
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (i != 1 || j != 1 || k != 0 || optidx != 2 || ec != 0) {
+    fprintf (stderr, "fail test %d / i:%d j:%d k:%d optidx:%d ec:%d\n", testno, i, j, k, optidx, ec);
     grc = 1;
   }
 
-  /* test 32 - empty value  */
+  /* test 31 - empty value  */
   ++testno;
   i = 0;
   j = 0;
@@ -959,10 +998,11 @@ main (argc, argv)
   av[0] = tmp;
   av[1] = "-i=";
   av[2] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_MODERN, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (i != 0 || optidx != 2) {
-    fprintf (stderr, "fail test %d\n", testno);
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (i != 0 || optidx != 2 || ec != 0) {
+    fprintf (stderr, "fail test %d / i:%d optidx:%d ec:%d\n", testno, i, optidx, ec);
     grc = 1;
   }
 
@@ -976,10 +1016,11 @@ main (argc, argv)
   av[0] = tmp;
   av[1] = "-i";
   av[2] = NULL;
+  ec = 0;
   fprintf (stderr, "** expect argument missing\n");
   optidx = getoptn (GETOPTN_MODERN, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (i != 0 || optidx != 2) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (i != 0 || optidx != 2 || ec != 1) {
     fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
@@ -995,10 +1036,11 @@ main (argc, argv)
   av[0] = tmp;
   av[1] = "-f1=7";
   av[2] = NULL;
+  ec = 0;
   fprintf (stderr, "** expect invalid size\n");
   optidx = getoptn (GETOPTN_MODERN, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (i != 0 || l != 0 || optidx != 2) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (i != 0 || l != 0 || optidx != 2 || ec != 1) {
     fprintf (stderr, "fail test %d; %d %ld %d\n", testno, i, l, optidx);
     grc = 1;
   }
@@ -1014,10 +1056,11 @@ main (argc, argv)
   av[0] = tmp;
   av[1] = "-f2=7";
   av[2] = NULL;
+  ec = 0;
   fprintf (stderr, "** expect invalid size\n");
   optidx = getoptn (GETOPTN_MODERN, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (i != 0 || l != 0 || optidx != 2) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (i != 0 || l != 0 || optidx != 2 || ec != 1) {
     fprintf (stderr, "fail test %d; %d %ld %d\n", testno, i, l, optidx);
     grc = 1;
   }
@@ -1033,10 +1076,11 @@ main (argc, argv)
   av[0] = tmp;
   av[1] = "-f3=7";
   av[2] = NULL;
+  ec = 0;
   fprintf (stderr, "** expect invalid size\n");
   optidx = getoptn (GETOPTN_MODERN, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (i != 0 || l != 0 || optidx != 2) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (i != 0 || l != 0 || optidx != 2 || ec != 1) {
     fprintf (stderr, "fail test %d; %d %ld %d\n", testno, i, l, optidx);
     grc = 1;
   }
@@ -1054,9 +1098,10 @@ main (argc, argv)
   av[2] = "--";
   av[3] = "abc";
   av[4] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_MODERN, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (i != 7 || optidx != 3) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (i != 7 || optidx != 3 || ec != 0) {
     fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
@@ -1073,9 +1118,10 @@ main (argc, argv)
   av[1] = "-i=7";
   av[2] = "abc";
   av[3] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_MODERN, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (i != 7 || optidx != 2) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (i != 7 || optidx != 2 || ec != 0) {
     fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
@@ -1092,9 +1138,10 @@ main (argc, argv)
   av[1] = "-s";
   av[2] = "-s";
   av[3] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_MODERN, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (strcmp (s, "-s") != 0 || optidx != 3) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (strcmp (s, "-s") != 0 || optidx != 3 || ec != 0) {
     fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
@@ -1113,9 +1160,10 @@ main (argc, argv)
   av[3] = "-s";
   av[4] = "abc";
   av[5] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_LEGACY, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (strcmp (s, "abc") != 0 || i != 1 || j != 1 || optidx != 5) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (strcmp (s, "abc") != 0 || i != 1 || j != 1 || optidx != 5 || ec != 0) {
     fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
@@ -1132,9 +1180,10 @@ main (argc, argv)
   av[1] = "-bcs";
   av[2] = "abc";
   av[3] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_LEGACY, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (strcmp (s, "abc") != 0 || i != 1 || j != 1 || optidx != 3) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (strcmp (s, "abc") != 0 || i != 1 || j != 1 || optidx != 3 || ec != 0) {
     fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
@@ -1148,9 +1197,10 @@ main (argc, argv)
   av[1] = "-s2";
   av[2] = "abc";
   av[3] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_MODERN, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (strcmp (s2, "abc") != 0 || optidx != 3) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (strcmp (s2, "abc") != 0 || optidx != 3 || ec != 0) {
     fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
@@ -1164,9 +1214,10 @@ main (argc, argv)
   av[1] = "-s2";
   av[2] = "abcd";
   av[3] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_MODERN, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (strcmp (s2, "abcd") != 0 || optidx != 3) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (strcmp (s2, "abcd") != 0 || optidx != 3 || ec != 0) {
     fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
@@ -1180,9 +1231,10 @@ main (argc, argv)
   av[1] = "-s2";
   av[2] = "abcde";
   av[3] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_MODERN, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (strcmp (s2, "abcd") != 0 || optidx != 3) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (strcmp (s2, "abcd") != 0 || optidx != 3 || ec != 0) {
     fprintf (stderr, "fail test %d: %s\n", testno, s2);
     grc = 1;
   }
@@ -1196,9 +1248,10 @@ main (argc, argv)
   av[1] = "-s2";
   av[2] = "abcdef";
   av[3] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_MODERN, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (strcmp (s2, "abcd") != 0 || optidx != 3) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (strcmp (s2, "abcd") != 0 || optidx != 3 || ec != 0) {
     fprintf (stderr, "fail test %d: %s\n", testno, s2);
     grc = 1;
   }
@@ -1212,10 +1265,11 @@ main (argc, argv)
   av[1] = "-np1";
   av[2] = "abcdef";
   av[3] = NULL;
+  ec = 0;
   fprintf (stderr, "** expect invalid pointer\n");
   optidx = getoptn (GETOPTN_MODERN, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (strcmp (s2, "") != 0) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (strcmp (s2, "") != 0 || ec != 1) {
     fprintf (stderr, "fail test %d: %s %d\n", testno, s2, optidx);
     grc = 1;
   }
@@ -1229,10 +1283,11 @@ main (argc, argv)
   av[1] = "-np2";
   av[2] = "abcdef";
   av[3] = NULL;
+  ec = 0;
   fprintf (stderr, "** expect invalid pointer\n");
   optidx = getoptn (GETOPTN_MODERN, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (strcmp (s2, "") != 0) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (strcmp (s2, "") != 0 || ec != 1) {
     fprintf (stderr, "fail test %d: %s %d\n", testno, s2, optidx);
     grc = 1;
   }
@@ -1246,10 +1301,11 @@ main (argc, argv)
   av[1] = "-np3";
   av[2] = "abcdef";
   av[3] = NULL;
+  ec = 0;
   fprintf (stderr, "** expect invalid pointer\n");
   optidx = getoptn (GETOPTN_MODERN, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (strcmp (s2, "") != 0) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (strcmp (s2, "") != 0 || ec != 1) {
     fprintf (stderr, "fail test %d: %s %d\n", testno, s2, optidx);
     grc = 1;
   }
@@ -1265,9 +1321,10 @@ main (argc, argv)
   av[0] = tmp;
   av[1] = "-z3";
   av[2] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_LEGACY, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (i != 0 || j != 1) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (i != 0 || j != 1 || ec != 0) {
     fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
@@ -1280,9 +1337,10 @@ main (argc, argv)
   av[0] = tmp;
   av[1] = "-c";
   av[2] = NULL;
+  ec = 0;
   optidx = getoptn (GETOPTN_LEGACY, ac, av,
-       sizeof (opts) / sizeof (getoptn_opt_t), opts);
-  if (i != 0) {
+       sizeof (opts) / sizeof (getoptn_opt_t), opts, &ec);
+  if (i != 0 || ec != 0) {
     fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
