@@ -1,7 +1,5 @@
 /*
- * $Id$
- * $Source$
- * Copyright 2011-2013 Brad Lanam, Walnut Creek, CA
+ * Copyright 2011-2018 Brad Lanam, Walnut Creek, CA
  */
 
 #ifndef DI_INC_GETOPTN_H_
@@ -59,6 +57,6 @@ typedef struct {
 } getoptn_opt_t;
 
 extern int getoptn _((int style, int argc, const char * const argv [],
-      Size_t optcount, getoptn_opt_t opts []));
+      Size_t optcount, getoptn_opt_t opts [], int *errorCount));
 
 #endif /*DI_INC_GETOPTN_H_ */
