@@ -8,6 +8,12 @@ maindoquery $1 $_MKC_ONCE
 getsname $0
 dosetup $@
 
+perl -v > /dev/null 2>&1
+rc=$?
+if [ $rc -ne 0 ] ; then
+  exit 166
+fi
+
 cd $_MKCONFIG_RUNTOPDIR
 grc=0
 
