@@ -17,12 +17,12 @@ _MKCONFIG_VERSION=`cat ${_MKCONFIG_DIR}/VERSION`
 export _MKCONFIG_VERSION
 
 # posh set command doesn't output correct data; don't bother with it.
-# yash has quoting/backquote issues
+# older yash has quoting/backquote issues (what version did this get fixed?)
 # zsh is not bourne shell compatible
 #   set | grep can be fixed (nulls are output) with: set | strings | grep
 #   and 'emulate ksh' can be set in mkconfig.sh, but there
 #   are more issues, and I'm not interested in tracking them down.
-tryshell="ash bash dash ksh ksh88 ksh93 mksh pdksh sh sh5"
+tryshell="ash bash bash2 bash3 bash4 bash5 dash ksh ksh88 ksh93 mksh pdksh sh sh5 osh yash"
 
 mkconfigversion () {
   echo "mkconfig version ${_MKCONFIG_VERSION}"
@@ -155,7 +155,7 @@ _HERE_
 # use the faster method $((expr)) if possible.
 test_math () {
   shhasmath=0
-  (eval 'x=1;y=$(($x+1)); test z$y = z2') 2>/dev/null
+  (eval 'x=1;w=0+1;y=$(($x+1));v=$(($w)); test z$y = z2 -a z$v = z1 ') 2>/dev/null
   if [ $? -eq 0 ]; then
     shhasmath=1
     eval 'domath () { mthvar=$1; mthval=$(($2)); eval $mthvar=$mthval; }'
@@ -253,6 +253,10 @@ getshelltype () {
     shvers=$YASH_VERSION
     shell=yash
     baseshell=yash
+  elif [ "$OIL_VERSION" != "" ]; then
+    shvers=$OIL_VERSION
+    shell=osh
+    baseshell=osh
   fi
 
   if [ $dispshell = sh -a $dispshell != $shell ]; then
@@ -282,7 +286,7 @@ doshelltest () {
   fi
 
   getshelltype  # for display of error below
-  chkshell
+  chkshell "" $shell
   if [ $? -ne 0 ]; then
     echo "The shell in use ($dispshell) does not have the correct functionality:" >&2
     echo $chkmsg >&2
@@ -317,15 +321,30 @@ chkshell () {
   if [ "$1" = "echo" ]; then
     doecho=T
   fi
+  shellpath=$2
 
   grc=0
 
+  case $shellpath in
+    *yash)
+      # reject older versions of yash
+      # I do not know in what version the quoting/backquoting issues
+      # got fixed.
+      rc=`echo "$YASH_VERSION < 2.48" | bc -l`
+      if [ $rc -eq 1 ]; then
+        chkmsg="${chkmsg}
+  older versions of yash are not supported"
+        grc=1
+      fi
+      ;;
+  esac
+
   chkmsg=""
   # test to make sure the set command works properly
   # some shells output xyzzy=abc def
   # some shells output xyzzy='abc def'
   # some shells output xyzzy=$'abc def' (ok; handled in mkconfig.sh)
-  # yash does this correctly, but has quoting/backquote issues
+  # yash does this correctly, but had quoting/backquote issues in older versions.
   (
     cmd='xyzzy="abc def"; val=`set | grep "^xyzzy"`; test "$val" = "xyzzy=abc def"'
     eval $cmd 2>/dev/null
