@@ -64,7 +64,7 @@ getlistofshells () {
     for s in $tryshell ; do
       rs=$d/$s
       if [ -x $rs ]; then
-        while [ -h $rs ]; do
+        while [ -h $rs -a $s != osh ]; do
           ors=$rs
           rs="`ls -l $rs | sed 's/.* //'`"
           case $rs in
@@ -77,7 +77,7 @@ getlistofshells () {
 
           # /etc/alternatives/xxx has some weird names w/dots.
           # all ksh* are ksh
-          # anything not ksh/bash/zsh is sh
+          # anything not ksh/bash/zsh/osh is sh
           # if the name is sh->bash or sh->ksh; don't follow symlink.
           ts=`echo $rs | sed -e 's,.*[/\.],,' \
               -e 's/ksh88/ksh/' -e 's/ksh93/ksh/' `
@@ -138,7 +138,7 @@ ${inode}"
   for s in $tshelllist; do
     putsnonl "  check $s" >&8
     putsnonl "   $s"
-    cmd="$s -c \". $_MKCONFIG_DIR/bin/shellfuncs.sh;chkshell echo\""
+    cmd="$s -c \". $_MKCONFIG_DIR/bin/shellfuncs.sh;chkshell echo $s\""
     eval $cmd >&8 2>&1
     rc=$?
     cmd="$s -c \". $_MKCONFIG_DIR/bin/shellfuncs.sh;getshelltype $s echo\""
@@ -427,7 +427,10 @@ while read tline; do
     src=$?
   fi
 
-  if [ $src -ne 0 ]; then
+  if [ $src -eq 166 ]; then
+    echo " ... skipped"
+    echo " skipped" >&8
+  elif [ $src -ne 0 ]; then
     src=1
     grc=1
     if [ $tbase = c-compiler -a $grc -ne 0 ]; then
